@@ -1,5 +1,5 @@
 #calculates final z-scores and factor scores, and extracts main results for Q method
-qzscores <- function(dataset, nfactors, loa=loa, flagged=flagged, forced=TRUE, distribution=NA) {    
+qzscores <- function(dataset, nfactors, loa, flagged, forced = TRUE, distribution = NULL) {    
   # calculate number of Q sorts and number of statements
   nstat <- nrow(dataset)
   nqsorts <- ncol(dataset)
@@ -46,9 +46,13 @@ qzscores <- function(dataset, nfactors, loa=loa, flagged=flagged, forced=TRUE, d
   #D. FACTOR SCORES: rounded z-scores
   if (forced) {
     qscores <- sort(dataset[,1], decreasing=FALSE)
-  } else {
+    if (sum(apply(dataset, 2, function(x) sort(x) != qscores)) > 0) stop("Q method input: The argument 'forced' is set as 'TRUE', but your data contains one or more Q-sorts that do not to follow the same distribution.")
+  }
+  if (!forced) {
+    if (is.null(distribution)) stop("Q method input: The argument 'forced' is set as 'FALSE', but no distribution has been provided in the argument 'distribution'.")
+    if (length(distribution) != nrow(dataset)) stop("Q method input: The length of the distribution provided does not match the number of statements.")
+    if (!is.numeric(distribution) & !is.integer(distribution)) stop("Q method input: The distribution provided contains non-numerical values.")
     qscores <- sort(distribution, decreasing=FALSE)
-    if (length(distribution) != nrow(dataset) | (class(distribution)[1] != "numeric" & class(distribution) != "integer")) stop("Q method input: The distribution of items was set as non-forced and the distribution provided is not suitable (it is the wrong length or it is non numerical)")
   }
   zsc_n <- as.data.frame(zsc)
   f <- 1
@@ -75,15 +79,17 @@ qzscores <- function(dataset, nfactors, loa=loa, flagged=flagged, forced=TRUE, d
   brief$date <- date()
   brief$nstat <- nstat
   brief$nqsorts <- nqsorts
+  brief$distro <- forced
   brief$nfactors <- nfactors
-  brief$rotation <- "unknown"
-  brief$cor.method <- "unknown"
+  brief$rotation <- "Unknown: loadings were provided separately."
+  brief$cor.method <- "Unknown: loadings were provided separately."
   brief$info <- c("Q-method z-scores.",
                   paste0("Finished on:             ", brief$date), 
                   paste0("Original data:           ", brief$nstat, " statements, ", brief$nqsorts, " Q-sorts"),
+                  paste0("Forced distribution:     ", brief$distro),
                   paste0("Number of factors:       ", brief$nfactors),
                   paste0("Rotation:                ", brief$rotation),
-                  paste0("Flagging:                unknown"),
+                  paste0("Flagging:                Unknown: flagged Q-sorts were provided separately."),
                   paste0("Correlation coefficient: ", brief$cor.method))
   # brief <- paste0("z-scores calculated on ", date(), ". Original data: ", nstat, " statements, ", nqsorts, " Q-sorts. Number of factors: ",nfactors,".")
   qmethodresults <- list()
